@@ -648,4 +648,6 @@ class SQLiteHandler(object):
 
     def get_complete_path(self):
         
-        return os.path.join(self.path, self.filename + self.extension)
\ No newline at end of file
+        complete_path = os.path.join(self.path, self.filename + self.extension)
+        print(f"complete_path is {complete_path}")
+        return complete_path
\ No newline at end of file
